@@ -4,9 +4,6 @@ use strict;
 use warnings;
 use DynaLoader;
 
-# Make sure debugging with Data::Dumper is more easily comparable:
-$Data::Dumper::Sortkeys = 1;
-
 # different files, but same package
 # require them here to avoid dependencies
 use URPM::Build;
@@ -14,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = 'v5.26.1';
+our $VERSION = '5.01';
 
 URPM->bootstrap($VERSION);
 
@@ -191,7 +188,7 @@ sub traverse_tag_find {
 #- this is used when faking a URPM::DB: $urpm can be used as-a $db
 #- (used for urpmi --env)
 sub create_transaction {
-    my ($_urpm) = @_; # same args as URPM.xs:create_transaction()
+    my ($urpm) = @_;
     die "Installing is not supported with a fake environment!";
 }
 
@@ -768,8 +765,6 @@ Just the provided package name.
 
 =item $package->requires()
 
-=item $package->recommends()
-
 Full requires tags
 
 =item $package->requires_nosense()
@@ -840,11 +835,6 @@ Options are:
     update => 0 / 1 : indicates whether this is an upgrade
     excludepath => [ ... ]
 
-=item $trans->addReinstall($pkg)
-
-Adds a package to be re-installed to the transaction represented by $trans.
-$pkg is an C<URPM::Package> object.
-
 =item $trans->remove($name)
 
 Adds a package to be erased to the transaction represented by $trans.
@@ -876,13 +866,11 @@ It's usually the $urpm object.
 Recognized options are:
 
     callback_close  => sub { ... }
-    callback_elem   => sub { ... }
     callback_error  => sub { ... }
     callback_inst   => sub { ... }
     callback_open   => sub { ... }
     callback_trans  => sub { ... }
     callback_uninst => sub { ... }
-    callback_verify => sub { ... }
     delta => used for progress callbacks (trans, uninst, inst)
     excludedocs => 0 / 1
     force => 0 / 1
@@ -903,7 +891,7 @@ C<$cb_type> is one of 'open' or 'close'.
 
 Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>)
 
-C<$cb_type> is one of 'elem', 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
+C<$cb_type> is one of 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
 For 'error', it can be 'cpio', 'script' or 'unpack'.
 
 The purpose of those callbacks is to report progress (the two last parameters (C<$amount> & C<$total>) enable to compute progress percentage).
@@ -1052,8 +1040,6 @@ B<transaction_state>: $state object
 
 The L<URPM::Resolve> implements the resolving bits.
 
-The L<URPM::Signature> implements the pubkey bits.
-
 The L<urpm> package is a higher level module used by the urpmi command line tool,
 the rpmdrake GUI and the drakx installer.
 
@@ -1063,7 +1049,7 @@ Copyright 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright 2005, 2006, 2007, 2008 Mandriva SA
 
-Copyright 2011, 2012, 2013, 2014, 2015, 2016 Mageia
+Copyright 2011, 2012, 2013 Mageia
 
 FranE<ccedil>ois Pons (original author), Rafael Garcia-Suarez, Pixel, Thierry Vignaud <tv@mageia.org> (current maintainer)
 
